@@ -3,16 +3,16 @@
 # flake8: noqa
 
 """
-    GroundX API
+    GroundX APIs
 
-    Ground Your RAG Apps in Fact not Fiction
+    RAG Made Simple, Secure and Hallucination Free
 
-    The version of the OpenAPI document: 1.0.0
-    Contact: support@groundx.ai
-    Created by: https://www.groundx.ai/
+    The version of the OpenAPI document: 1.3.26
+    Contact: support@eyelevel.ai
+    Created by: https://www.eyelevel.ai/
 """
 
-__version__ = "1.3.22"
+__version__ = "1.3.23"
 
 # import ApiClient
 from groundx.api_client import ApiClient
